from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("schedule", "0007_merge_text_fields")]

    operations = [
        migrations.AlterField(
            model_name="calendar",
            name="slug",
            field=models.SlugField(verbose_name="slug", max_length=200, unique=True),
        )
    ]



# Generated by Django 2.0 on 2018-01-09 05:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("schedule", "0008_calendar_slug_unique"),
        ("schedule", "0008_gfk_index"),
    ]

    operations = []
